# Spatial transcriptomics

```{toctree}
:maxdepth: 1

notebooks/spatial/DestVI_tutorial
notebooks/spatial/DestVI_in_R
notebooks/spatial/gimvi_tutorial
notebooks/spatial/tangram_scvi_tools
notebooks/spatial/stereoscope_heart_LV_tutorial
notebooks/spatial/cell2location_lymph_node_spatial_tutorial
```
